## cbr site - config data

Here is the output from the main api methods available at /docs

<webc-api-to-json api_path="/config/status"               ></webc-api-to-json>

<webc-api-to-json api_path="/config/version"              ></webc-api-to-json>
<webc-api-to-json api_path="/site_info/cbr-config-active" ></webc-api-to-json>
<webc-api-to-json api_path="/site_info/cbr-site-info"     ></webc-api-to-json>

